/**
 * A joogl ambient light object.  
 * <p>
 * This object creates an ambient light when attached to the scene graph.    
 *
 * @version 	1.00
 * @author      Blair MacIntyre
 */

public class jooglAmbientLight extends jooglLight {
    
    /**
     * Constructor function for an AmbientLight, using floats.
     * <p>
     * Specify the RGB values for the light color.  A default intensity of 1.0 is used.
     * 
     * @param r		the red component of the light, from 0 to 1
     * @param g		the green component of the light, from 0 to 1
     * @param b		the blue component of the light, from 0 to 1
     */
    public jooglAmbientLight(float _r, float _g, float _b)
    {
        super(_r, _g, _b);
    }    
    
    /**
     * Constructor function for an AmbientLight, using doubles.
     * <p>
     * Specify the RGB values for the light color.  A default intensity of 1.0 is used.
     * 
     * @param r		the red component of the light, from 0 to 1
     * @param g		the green component of the light, from 0 to 1
     * @param b		the blue component of the light, from 0 to 1
     */
    public jooglAmbientLight(double _r, double _g, double _b)
    {
        super((float)_r, (float)_g, (float)_b);
    }    
    
    /**
    * Activate the light.
    * <p>
    * This is an internal function, called during rendering to turn on this light using a specified OpenGL 
    * light number.   If the light is on, the OpenGL light will be set to be the appropriate ambient light.
    *
    * @param lightNum    set OpenGL light "lightNum" to this ambient light
    * @return   Indicates if the light is turned on or off.
    */
    protected boolean activate(int lightNum)
    {
    }
}
