/**
 * The dynamic shading mode property node.
 * <p>
 * The object is dynamic.  It must be subclassed, and have its abstract "getValue" method overridden.
 * This method should compute the value of the property at the requested time.
 *
 * @version 	1.00
 * @author      Blair MacIntyre
 */

public abstract class jooglDynamicShadeMode extends jooglShadeMode {
    /** what is the time at which I was last cached? */
    protected long cacheTime = -1;
    
    /** 
     * Is this property object dynamic or static?
     * <p>
     * Override this method because this is a dynamic subclasses. 
     *
     * @return true because the property is dynamic.
     */
    protected boolean isDynamic()
    {	
        return true;
    }

    /** 
     * Get the value of the property at time t.
     * <p>
     * This method must be overridden with a method that computes the dynamic property value.
     *
     * @param time the time in milliseconds at which the property should be evaluated
     * @return the shade mode
     */
    public abstract int getValue(long time);
        
    /**
     * Internal Method, to cache the value of the property at time t in the property state variable.
     * The cache should not be recomputed if the time is the same as the previous call.
     * <p>
     * @param time the time in milliseconds at which the property should be evaluated
     */
    protected void cacheValue(long time)
    {
    }
}
