/**
 * The Visitor traverses the scene graph, updating properties, damaged geometry, 
 * and handling Light and Camera objects.
 * <p>
 * The necessary properties are pushed when a node is visited and popped when the node is left.
 *
 * @version 	1.00
 * @author      Blair MacIntyre
 */
public class jooglLightsCameraActionVisitor extends jooglVisitor {
    /** The time that properties should compute their value at.*/
    protected long time = -1;

    /** The dynamic flag, which will be true at the end of traversal if a dynamic property was encountered. */
    protected boolean dynamic = false;
    
    /** The next OpenGL light to use. */
    protected int next = GL_LIGHT0;

    /** The camera to look for. */
    protected jooglCamera cam = null;

    /** The default constructor. */
    public jooglLightsCameraActionVisitor ()
    {
        super();
    }

    /** A constructor that provides the first OpenGL light and the current camera object.
     * <p>
     * The specified light and camera are used during traversal.
     *
     * @param light the OpenGL light to use for the first light encountered.
     * @param rootCam the camera object that is currently used by the root object
     */
    public jooglLightsCameraActionVisitor (int light, jooglCamera rootCam)
    {
        super();
        cam = rootCam;
        next = light;
        dynamic = false;
    }

    /** 
     * Initialize the visitor to traverse a scene graph correctly.
     * <p>
     * Define the first OpenGL light and the current camera object.
     * The specified light and camera are used during traversal.
     * <p>
     * Set the time to use for dynamic properties.
     * <p>
     * This function also resets dynamic to false, on the assumption that we are about to start another 
     * traversal.
     *
     * @param light the OpenGL light to use for the first light encountered.
     * @param rootCam the camera object that is currently used by the root object
     * @param t the time value in milliseconds
     */
    public void setLightCameraTime(int light, jooglCamera rootCam, long t)
    {
        cam = rootCam;
        next = light;
        time = t;
        dynamic = false;
    }

    /** Get the value of the next light to be used (so we know how many were used).
     *
     * @return the integer value of the next OpenGL light to be used.
     */
    public int getNextLight()
    {
    }
    
    /** Were there any dynamic properties?
     * <p>
     * Can be called after traversal to see if there were any dynamic properties.
     *
     * @return true if there was at least one dynamic property encountered.
     */
    public boolean isDynamic()
    {
    }
    
    /** 
     * The action to be done when a node is first visited. 
     *
     * @param node the current node being visited
     */
    public void preAction(jooglNode node)
    {
    }
        
    /** 
     * The action to be done when a node has been visited and is being left. 
     * 
     * @param node the current node being visited
     */
    public void postAction(jooglNode node)
    {
    }
}
