/**
 * The abstract base class for all nodes node.
 * <p>
 * We keep track of the node properties here.  If we had a lot of properties 
 * (in the hundreds, for example), we would want to use a more generic method,
 * such as a key-value property list, 
 * but explicitly keeping track like this makes things simpler (and clearer).
 * <p>
 * If a property is null (the default), there is no property of that type on
 * this node, and so the property inherits down the graph.  
 * <p>
 * Setting the property (even if it does not change) should cause all the windows to redraw.
 * We do this because we do not want to keep track of which nodes and properties are in
 * which scene graph.  Furthermore, since changing a property does not cause the windows
 * to be redrawn, when a user changes a property they can simply reassign it to a node,
 * which forces a refresh of the windows.
 *
 * @version 	1.00
 * @author      Blair MacIntyre
 */

public abstract class jooglNode extends jooglObject {
    /** The material property */
    protected jooglMaterial material = null;
    /** The transform property */
    protected jooglTransform transform = null;
    /** The drawMode property */
    protected jooglDrawMode drawMode = null;
    /** The shadeMode property */
    protected jooglShadeMode shadeMode = null;
    /** The pickable property */
    protected jooglPickable pickable = null;
    
    /** The default constructor */
    public jooglNode ()
    {
        super();
    }
    
    /** Set the material property.
     * <p>
     * Set the material property for this node.  
     * 
     * @param _mat the new material property.
     */
    public void setMaterial(jooglMaterial _mat)
    {
        material = _mat;
    }
    
    /** Get the material property.
     * <p>
     * Retrieve the material property from this node.  
     * 
     * @return the current material property.
     */
    public jooglMaterial getMaterial()
    {
        return material;
    }
    
    /** Set the transform property.
     * <p>
     * Set the transform property for this node.  
     * 
     * @param _trans the new transform property.
     */
    public void setTransform(jooglTransform _trans)
    {
        transform = _trans;
    }
    
    /** Get the transform property.
     * <p>
     * Retrieve the transform property from this node.  
     * 
     * @return the current transform property.
     */
    public jooglTransform getTransform()
    {
        return transform;
    }
    
    /** Set the drawMode property.
     * <p>
     * Set the drawMode property for this node.  
     * 
     * @param dm the new drawMode property.
     */
    public void setDrawMode(jooglDrawMode dm)
    {
        drawMode = dm;
    }
    
    /** Get the drawMode property.
     * <p>
     * Retrieve the drawMode property from this node.  
     * 
     * @return the current drawMode property.
     */
    public jooglDrawMode getDrawMode()
    {
        return drawMode;
    }
    
    /** Set the shadeMode property.
     * <p>
     * Set the shadeMode property for this node.  
     * 
     * @param sm the new shadeMode property.
     */
    public void setShadeMode(jooglShadeMode sm)
    {
        shadeMode = sm;
    }
    
    /** Get the shadeMode property.
     * <p>
     * Retrieve the shadeMode property from this node.  
     * 
     * @return the current shadeMode property.
     */
    public jooglShadeMode getShadeMode()
    {
        return shadeMode;
    }
    
    /** Set the pickable property.
     * <p>
     * Set the pickable property for this node.  
     * 
     * @param p the new pickable property.
     */
    public void setPickable(jooglPickable p)
    {
        pickable = p;
    }
    
    /** Get the pickable property.
     * <p>
     * Retrieve the pickable property from this node.  
     * 
     * @return the current pickable property.
     */
    public jooglPickable getPickable()
    {	
        return pickable;
    }
}
