/**
 * The joogl orthographic camera object.
 * <p>
 * This object creates an orthographic camera, analogous to the standard OpenGL
 * glOrtho and gluLookat commands.
 * <p>
 * The parameters correspond to what you would use in OpenGL to create an
 * orthographic projection:
 * <pre>
 fx,fy,fz: the viewpoint ("from")
 tx,ty,tz: the lookat point ("to")
 ux,uy,uz: the up vector ("up")
 height: the height of orthographic window
 near,far: the clipping planes
 * </pre>
 *
 * @version 	1.00
 * @author      Blair MacIntyre
 */
 
 
public class jooglOrthographicCamera extends jooglCamera {
    /** the height of the orthographic window */
    protected double height; 
    
    /** 
     * A constructor for the orthographic camera.
     * <p>
     * Create an orthographic camera object to be used to view a scene graph.
     *
     * @param _fx  the x coordinate of the eyepoint
     * @param _fy  the y coordinate of the eyepoint
     * @param _fz  the z coordinate of the eyepoint
     * @param _tx  the x coordinate of the to point
     * @param _ty  the y coordinate of the to point
     * @param _tz  the z coordinate of the to point
     * @param _ux  the x coordinate of the up vector
     * @param _uy  the y coordinate of the up vector
     * @param _uz  the z coordinate of the up vector
     * @param _height  the height of the orthographic view
     * @param _near  the near clipping plane
     * @param _far   the far clipping plane
     */
    public jooglOrthographicCamera(double _fx, double _fy, double _fz, 
                        double _tx, double _ty, double _tz,
			double _ux, double _uy, double _uz,
			double _height,
                        double _near, double _far)
    {
        super(_fx, _fy, _fz, _tx, _ty, _tz, _ux, _uy, _uz, _near, _far);
	height = _height;
    }

    /** 
     * A constructor for the orthographic camera specifying only the orthographic window.
     * <p>
     * Create an orthographics camera using the default camera position and orientation
     * and a specified window.
     *
     * @param _height  the height of the orthographic view
     */
    public jooglOrthographicCamera(double _height)
    {
        super();
	height = _height;
    }
    
    /** 
     * A constructor for the orthographic camera specifying only the orthographic window.
     * <p>
     * Create an orthographics camera using the default camera position and orientation
     * and a window with a height of 2.
     */
    public jooglOrthographicCamera()
    {
        super();
	height = 2.0;
    }
    
    /** 
     * Set the height of the window.
     *
     * @param _height a double containing the new value
     */
    public void setHeight(double _height)
    {
	height = _height;
    }
    
    /** 
     * Get the height of the window.
     *
     * @return a double containing the current value
     */
    public double getHeight()
    {
        return height;
    }
    
    /** 
     * Internal method, called to set the current PROJECTION to correspond to this camera.
     * <p>
     * This method sets up the camera,
     * after transforming the parameters according to the camCoords transformation.
     */
    protected void apply(jooglTransform camCoords)
    {
    }
}
