import java.util.*;
import gl4java.*;

/**
 * The transformation property node.
 * <p>
 * Transformation properties can either be constant or time-variant
 * functions, as with all the properties.  Unlike the material,
 * shademodel and drawmode, the transformation properties COMPOSE as the 
 * graph is traversed: at any given node, the "current transformation"
 * is the composition of all transformations on the path from the root
 * node to the node in question.
 * <p>
 * If a node does not have a transformation property, it is equivalent to the
 * identity matrix. 
 * <p>
 * We provide a set of functions to compose common
 * transformations (translate, scale, rotate) with the current value. 
 * We also provide functions to replace or compose arbitrary transformation
 * matrices with the current transformation property.  
 * <p>
 * setIdentity() reinitializes the current transformation
 * property to the identity matrix.
 * <p>
 * If a node has a time-variant function for its transformation
 * property, the functions to change the transformation have no effect.
 * <p>
 * @version 	1.00
 * @author      Blair MacIntyre
 */
public class jooglTransform extends jooglProperty {
    /** The current transformation matrix value */
    protected double[] matrix = new double[16];

    /** Create a transformation containing the identity matrix. */
    public jooglTransform()
    {
        super(PROP_TRANSFORM);
        setIdentity();
    }
    
    /** 
     * Create a transformation identical to the supplied Transform.
     *
     * @param t a jooglTransform that this one should copy.
     */
    public jooglTransform(jooglTransform t)
    {
        super(PROP_TRANSFORM);
        setTransform(t.matrix);
    }
    
    /** 
     * Create a transformation identical to the supplied matrix.
     *
     * @param t a matrix that this one should copy.
     */
    public jooglTransform(double[] m)
    {
        super(PROP_TRANSFORM);
        setTransform(m);
    }
    
    /** 
     * Set the transformation matrix to be identical to the supplied matrix.
     *
     * @param t a matrix that this one should copy.
     * @return a reference to itself (this) so transformation commands can be chained.
     */
    public jooglTransform setTransform(double[] m)
    {
    }
    
    /** 
     * Set the transformation matrix to be identical to the supplied transformation.
     *
     * @param t a transform that this one should copy.
     * @return a reference to itself (this) so transformation commands can be chained.
     */
    public jooglTransform setTransform(jooglTransform m)
    {
    }

    /** 
     * Get the transformation matrix for this transform.
     *
     * @return a 16 element array containing the transformation
     */
    public double [] getTransform()
    {
    }
        
    /** 
     * Compose a translation onto the current transformation matrix.
     *
     * @param tx the x component of the translation.
     * @param ty the y component of the translation.
     * @param tz the z component of the translation.
     * @return a reference to itself (this) so transformation commands can be chained.
     */
    public jooglTransform translate(double tx, double ty, double tz)
    {
    }

    /** 
     * Compose a scale onto the current transformation matrix.
     *
     * @param sx the x component of the scale.
     * @param sy the y component of the scale.
     * @param sz the z component of the scale.
     * @return a reference to itself (this) so transformation commands can be chained.
     */
    public jooglTransform scale(double sx, double sy, double sz)
    {
    }

    /** 
     * Compose a rotation about X onto the end of the object transformation.
     *
     * @param angle the angle to rotate by, in degrees.
     * @return a reference to itself (this) so transformation commands can be chained.
     */
    public jooglTransform rotateX(double angle) 
    {
    }
    
    /** 
     * Compose a rotation about Y onto the end of the object transformation.
     *
     * @param angle the angle to rotate by, in degrees.
     * @return a reference to itself (this) so transformation commands can be chained.
     */
    public jooglTransform rotateY(double angle)
    {
    }
    
    /** 
     * Compose a rotation about Z onto the end of the object transformation.
     *
     * @param angle the angle to rotate by, in degrees.
     * @return a reference to itself (this) so transformation commands can be chained.
     */
    public jooglTransform rotateZ(double angle)
    {
    }

    /** 
     * Set the transformation to the identity matrix.
     *
     * @return a reference to itself (this) so transformation commands can be chained.
     */
    public jooglTransform setIdentity()
    {
    }
    
    /** 
     * Compose the supplied transformation matrix onto the end of the object transformation.
     *
     * @param m the transformation matrix.
     * @return a reference to itself (this) so transformation commands can be chained.
     */
    public jooglTransform multiply(double[] m)
    {
    }
    
    /** 
     * Compose the supplied transformation onto the end of the object transformation.
     *
     * @param m the transformation.
     * @return a reference to itself (this) so transformation commands can be chained.
     */
    public jooglTransform multiply(jooglTransform m)
    {
    }
    
    /** 
     * Get the value of the property at time t.
     *
     * @param time the time in milliseconds at which the property should be evaluated
     * @return the transformation in a 16 element array
     */
    public double[] getValue(long time)
    {
    }
    
    /**
     * Print the transformation matrix.
     * <p>
     * This method is useful for debugging.
     *
     * @return a reference to itself (this) so transformation commands can be chained.
     */
    public jooglTransform printMatrix()
    {
        System.out.println("[" + matrix[0] + ", " + matrix[1] + ", " + matrix[2] + ", " + matrix[3] + "]");
        System.out.println("[" + matrix[4] + ", " + matrix[5] + ", " + matrix[6] + ", " + matrix[7] + "]");
        System.out.println("[" + matrix[8] + ", " + matrix[9] + ", " + matrix[10] + ", " + matrix[11] + "]");
        System.out.println("[" + matrix[12] + ", " + matrix[13] + ", " + matrix[14] + ", " + matrix[15] + "]");
        return this;
    }
    
    /**
     * Internal Method, to cache the value of the property at time t in the property state variable.
     *
     * @param time the time in milliseconds at which the property should be evaluated
     */
    protected void cacheValue(long time)
    {
    }
    
    /** Push a transformation onto the transformation stack.
     * <p>
     * Hint:  you need to override this method here.
     */
    protected void push()
    {
    }
    
    /** Pop a transformation off the transformation stack.
     * <p>
     * Hint:  you need to override this method here.
     */
    protected void pop()
    {
    }

    /** Internal Method, set the OpenGL state for this property.  Called when the stacks are pushed and popped.
     * <p>
     * Only put things here that can be called multiple times safely. 
     */
    protected void apply()
    {
    }
    
    /** Multiply a vector by the transformation.
     *
     * @param x the x component of the vector.
     * @param y the y component of the vector.
     * @param z the z component of the vector.
     * @param r a 3 element matrix that the transformed vector will be returned in.
     */
    protected void multVector(double x, double y, double z, double[] r)
    {
    }

    /** Multiply a point by the transformation.
     *
     * @param x the x component of the point.
     * @param y the y component of the point.
     * @param z the z component of the point.
     * @param r a 3 element matrix that the transformed point will be returned in.
     */
    protected void multPoint(double x, double y, double z, double[] r)
    {
    }
}
