import java.util.*;

/**
 * The Visitor subclasses are used to traverse the scene graph of Group nodes.
 *
 * @version 	1.00
 * @author      Blair MacIntyre
 */

public abstract class jooglVisitor extends jooglObject {
    /** The default constructor. */
    public jooglVisitor ()
    {
        super();
    }

    /** Visit a node in the scene graph.
     * <p>
     * When a node is visited, a "preAction" is executed on the node, then all the 
     * children of the node are visited (if it is a Group), and finally a 
     * "postAction" is performed before returning.
     *
     * @param node the node to visit.
     */
    public void visit(jooglNode node)
    {
        preAction(node);
        if (node instanceof jooglGroup)
        {
            Iterator i = ((jooglGroup)node).children.iterator();
            while (i.hasNext()) 
            {
                visit((jooglNode)(i.next()));
            }
        }
        postAction(node);
    }
    
    /** The action to be done when the node is visited, before visiting the children. */
    public void preAction(jooglNode node)
    {
    }
        
    /** The action to be done when the node is visited, after visiting the children. */
    public void postAction(jooglNode node)
    {
    }
}
